# FairSwap

These contracts support the paper Fair Swap published at ACM CCS 2018.

All contracts provided in this github are a proof of concept implementation and are not audited for implmentation bugs. 
Use with caution.
